#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-6G0vYaqFLHZ9piv0CIHnqq
key:                  warp-3.4.0-6G0vYaqFLHZ9piv0CIHnqq
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  6cf156d9f922bedaac9af47cdb7fc07f
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-6G0vYaqFLHZ9piv0CIHnqq
depends:
    array-0.5.6.0 auto-update-0.1.6-8VIW6yLGrtjXOUYU19YSI base-4.18.2.1
    bsb-http-chunked-0.0.0.4-I69Ti8haPMnGNdy6EXRODZ bytestring-0.11.5.3
    case-insensitive-1.2.1.0-5S5ro0Sr4ku7ksxXlk9v1u containers-0.6.7
    crypton-x509-1.7.7-HMLwIIUDMv1KBQgaRD1sb4 ghc-prim-0.10.0
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    http-date-0.0.11-6406fxibUPlKJgZt39SVAA
    http-types-0.12.4-GbnA9GBjJLTWEnI56wc3O
    http2-5.1.1-JSfKazSxPgNEHjPIO3Xsir
    iproute-1.7.15-6lE7lm6F5wM5c7pzGBnkDy
    network-3.1.4.0-8vuuKMF6w9xKjPzP5P4pIh
    recv-0.1.1-DEpg3dxn5nJGKxP9KX1Mqv
    simple-sendfile-0.2.32-GO9kLqtSrjL8f8mCKa6OtN stm-2.5.1.0
    streaming-commons-0.2.3.1-DQzXRCxPqvy6dF3GI89UsZ text-2.0.2
    time-manager-0.0.1-22ao4Qv9XjE8QDunjZ8iMt unix-2.8.4.0
    unliftio-0.2.25.1-2YWCJQ4bXOaKV2dFmJlGMH
    vault-0.3.1.6-LZWsK7dsgVF1l88n23pw8P
    wai-3.2.4-Jk1G9YwNfdE88VOGwH3kFJ word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

